pub struct BinaryFrameEncoder;Expand description
Simple little-endian binary frame encoder.
Implementations
Sourceimpl BinaryFrameEncoder
impl BinaryFrameEncoder
Sourcepub fn encode_command_dispatch_envelope(
&mut self,
station_id: StationId,
envelope: &CommandEnvelope,
out: &mut Vec<u8>,
) -> Result<(), BinaryEncodeError>
pub fn encode_command_dispatch_envelope( &mut self, station_id: StationId, envelope: &CommandEnvelope, out: &mut Vec<u8>, ) -> Result<(), BinaryEncodeError>
Encodes a stamped command envelope directly as a dispatch frame.
This avoids cloning the opaque payload into an intermediate owned
CommandDispatchFrame when the frame is immediately transmitted.