pub struct StationEventFrame {
pub event_id: EventId,
pub source_station: StationId,
pub target_station: StationId,
pub source_tick: Tick,
pub target_tick: Tick,
pub priority: EventPriority,
pub kind: EventKind,
}Expand description
Cross-station event frame.
Fields
event_id: EventIdIdempotency key.
source_station: StationIdSource station.
target_station: StationIdTarget station.
source_tick: TickTick observed at source.
target_tick: TickTick at which target should apply the event.
priority: EventPriorityPriority class.
kind: EventKindEvent payload kind.
Implementations
Sourceimpl StationEventFrame
impl StationEventFrame
Sourcepub fn from_event(event: &StationEvent) -> Self
pub fn from_event(event: &StationEvent) -> Self
Converts a runtime station event into a wire frame.
Sourcepub fn into_event(self) -> StationEvent
pub fn into_event(self) -> StationEvent
Converts a wire frame into a runtime station event.