Crate sectorsync_wire

Crate sectorsync_wire 

Wire frame traits and default frame shapes for SectorSync.

Structs

BarrierFrame
Runtime barrier notification frame.
BinaryFrameDecoder
Simple little-endian binary frame decoder.
BinaryFrameEncoder
Simple little-endian binary frame encoder.
CommandAckFrame
Command acknowledgement frame.
CommandDispatchFrame
Internal gateway-to-station command dispatch frame.
CommandFrame
Client command ingress frame.
ComponentDelta
Component delta included in an entity delta.
ComponentSelection
Component selection for frame building.
EntityDelta
Entity delta included in a replication frame.
ReplicationFrame
Replication frame metadata produced per client.
ReplicationFrameBuild
Result of building a replication frame.
ReplicationFrameBuildStats
Frame builder statistics.
ReplicationFrameBuilder
Builds concrete replication frames from a core replication plan.
ReplicationFrameLimits
Limits used by ReplicationFrameBuilder.
StationEventFrame
Cross-station event frame.

Enums

BinaryDecodeError
Binary decode error.
BinaryEncodeError
Binary encode error.
FrameKind
Runtime frame kind.
RuntimeFrame
Decoded runtime frame.

Traits

FrameDecoder
Decodes frames from bytes.
FrameEncoder
Encodes frames into bytes.