pub struct ReplicationFrameBuilder {
pub limits: ReplicationFrameLimits,
}Expand description
Builds concrete replication frames from a core replication plan.
Fields
limits: ReplicationFrameLimitsBuilder limits.
Implementations
Sourceimpl ReplicationFrameBuilder
impl ReplicationFrameBuilder
Sourcepub const fn new(limits: ReplicationFrameLimits) -> Self
pub const fn new(limits: ReplicationFrameLimits) -> Self
Creates a frame builder with explicit limits.
Sourcepub fn build(
&self,
client_id: ClientId,
server_tick: Tick,
station: &Station,
plan: &ReplicationPlan,
components: &ComponentStore,
selection: &ComponentSelection,
) -> ReplicationFrameBuild
pub fn build( &self, client_id: ClientId, server_tick: Tick, station: &Station, plan: &ReplicationPlan, components: &ComponentStore, selection: &ComponentSelection, ) -> ReplicationFrameBuild
Builds a frame from a station plan and component store.